@@ -27,7 +27,6 @@ use CSS::Sass;
 
 ################################################################################
 package CSS::Sass::Type;
-our $VERSION = "v3.0.1";
 ################################################################################
 use CSS::Sass qw(import_sv);
 ################################################################################
@@ -169,7 +168,7 @@ sub value {
 	if (scalar(@_) > 1) {
 		${$_[0]}->[0] = defined $_[1] ? $_[1] : 0;
 	}
-	sprintf "%g", ${$_[0]}->[0];
+	${$_[0]}->[0];
 }
 
 sub unit {
@@ -180,7 +179,7 @@ sub unit {
 }
 
 sub stringify {
-	sprintf "%g%s", @{${$_[0]}};
+	join '', @{${$_[0]}}
 }
 
 sub equals {
@@ -405,26 +404,13 @@ L<CSS::Sass>
 David Caldwell E<lt>david@porkrind.orgE<gt>  
 Marcel Greter E<lt>perl-libsass@ocbnet.chE<gt>
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-The MIT License (MIT)
+Copyright (C) 2013 by David Caldwell  
+Copyright (C) 2014 by Marcel Greter
 
-Permission is hereby granted, free of charge, to any person obtaining a copy
-of this software and associated documentation files (the "Software"), to deal
-in the Software without restriction, including without limitation the rights
-to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the Software is
-furnished to do so, subject to the following conditions:
-
-The above copyright notice and this permission notice shall be included in
-all copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-THE SOFTWARE.
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.12.4 or,
+at your option, any later version of Perl 5 you may have available.
 
 =cut
